@@ -21,12 +21,13 @@ class Cgroups(Plugin, DebianPlugin, UbuntuPlugin, CosPlugin):
     def setup(self):
 
         self.add_file_tags({
-            '/proc/1/cgroups': 'insights_init_process_cgroup'
+            '/proc/1/cgroups': 'init_process_cgroup'
         })
 
         self.add_copy_spec([
             "/proc/cgroups",
-            "/sys/fs/cgroup"
+            "/sys/fs/cgroup",
+            "/proc/[0-9]*/cgroup",
         ])
 
         self.add_cmd_output("systemd-cgls")
@@ -38,7 +39,7 @@ class Cgroups(Plugin, DebianPlugin, UbuntuPlugin, CosPlugin):
 class RedHatCgroups(Cgroups, RedHatPlugin):
 
     def setup(self):
-        super(RedHatCgroups, self).setup()
+        super().setup()
         self.add_copy_spec([
             "/etc/sysconfig/cgconfig",
             "/etc/sysconfig/cgred",
