@@ -15,7 +15,7 @@ class ConnectionAbortedTests(SynchronousTestCase):
     Tests for the L{twisted.internet.error.ConnectionAborted} exception.
     """
 
-    def test_str(self):
+    def test_str(self) -> None:
         """
         The default message of L{ConnectionAborted} is a sentence which points
         to L{ITCPTransport.abortConnection()}
@@ -25,7 +25,7 @@ class ConnectionAbortedTests(SynchronousTestCase):
             str(error.ConnectionAborted()),
         )
 
-    def test_strArgs(self):
+    def test_strArgs(self) -> None:
         """
         Any arguments passed to L{ConnectionAborted} are included in its
         message.
