@@ -1,8 +1,8 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-14.
-# Copyright (C) 2002-2016 Guido Flohr <guido.flohr@cantanea.com>,
+# Conversion routines for ISO-8859-5.
+# Copyright (C) 2002-2017 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_14;
+package Locale::RecodeData::ISO_8859_5;
 
 use strict;
 
@@ -187,101 +187,101 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0x1e02,
-    0x1e03,
-    0x00a3,
-    0x010a,
-    0x010b,
-    0x1e0a,
-    0x00a7,
-    0x1e80,
-    0x00a9,
-    0x1e82,
-    0x1e0b,
-    0x1ef2,
+    0x0401,
+    0x0402,
+    0x0403,
+    0x0404,
+    0x0405,
+    0x0406,
+    0x0407,
+    0x0408,
+    0x0409,
+    0x040a,
+    0x040b,
+    0x040c,
     0x00ad,
-    0x00ae,
-    0x0178,
-    0x1e1e,
-    0x1e1f,
-    0x0120,
-    0x0121,
-    0x1e40,
-    0x1e41,
-    0x00b6,
-    0x1e56,
-    0x1e81,
-    0x1e57,
-    0x1e83,
-    0x1e60,
-    0x1ef3,
-    0x1e84,
-    0x1e85,
-    0x1e61,
-    0x00c0,
-    0x00c1,
-    0x00c2,
-    0x00c3,
-    0x00c4,
-    0x00c5,
-    0x00c6,
-    0x00c7,
-    0x00c8,
-    0x00c9,
-    0x00ca,
-    0x00cb,
-    0x00cc,
-    0x00cd,
-    0x00ce,
-    0x00cf,
-    0x0174,
-    0x00d1,
-    0x00d2,
-    0x00d3,
-    0x00d4,
-    0x00d5,
-    0x00d6,
-    0x1e6a,
-    0x00d8,
-    0x00d9,
-    0x00da,
-    0x00db,
-    0x00dc,
-    0x00dd,
-    0x0176,
-    0x00df,
-    0x00e0,
-    0x00e1,
-    0x00e2,
-    0x00e3,
-    0x00e4,
-    0x00e5,
-    0x00e6,
-    0x00e7,
-    0x00e8,
-    0x00e9,
-    0x00ea,
-    0x00eb,
-    0x00ec,
-    0x00ed,
-    0x00ee,
-    0x00ef,
-    0x0175,
-    0x00f1,
-    0x00f2,
-    0x00f3,
-    0x00f4,
-    0x00f5,
-    0x00f6,
-    0x1e6b,
-    0x00f8,
-    0x00f9,
-    0x00fa,
-    0x00fb,
-    0x00fc,
-    0x00fd,
-    0x0177,
-    0x00ff,
+    0x040e,
+    0x040f,
+    0x0410,
+    0x0411,
+    0x0412,
+    0x0413,
+    0x0414,
+    0x0415,
+    0x0416,
+    0x0417,
+    0x0418,
+    0x0419,
+    0x041a,
+    0x041b,
+    0x041c,
+    0x041d,
+    0x041e,
+    0x041f,
+    0x0420,
+    0x0421,
+    0x0422,
+    0x0423,
+    0x0424,
+    0x0425,
+    0x0426,
+    0x0427,
+    0x0428,
+    0x0429,
+    0x042a,
+    0x042b,
+    0x042c,
+    0x042d,
+    0x042e,
+    0x042f,
+    0x0430,
+    0x0431,
+    0x0432,
+    0x0433,
+    0x0434,
+    0x0435,
+    0x0436,
+    0x0437,
+    0x0438,
+    0x0439,
+    0x043a,
+    0x043b,
+    0x043c,
+    0x043d,
+    0x043e,
+    0x043f,
+    0x0440,
+    0x0441,
+    0x0442,
+    0x0443,
+    0x0444,
+    0x0445,
+    0x0446,
+    0x0447,
+    0x0448,
+    0x0449,
+    0x044a,
+    0x044b,
+    0x044c,
+    0x044d,
+    0x044e,
+    0x044f,
+    0x2116,
+    0x0451,
+    0x0452,
+    0x0453,
+    0x0454,
+    0x0455,
+    0x0456,
+    0x0457,
+    0x0458,
+    0x0459,
+    0x045a,
+    0x045b,
+    0x045c,
+    0x00a7,
+    0x045e,
+    0x045f,
 );
 
 my @to_utf8 = (
@@ -446,101 +446,101 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xe1\xb8\x82",
-    "\xe1\xb8\x83",
-    "\xc2\xa3",
-    "\xc4\x8a",
-    "\xc4\x8b",
-    "\xe1\xb8\x8a",
-    "\xc2\xa7",
-    "\xe1\xba\x80",
-    "\xc2\xa9",
-    "\xe1\xba\x82",
-    "\xe1\xb8\x8b",
-    "\xe1\xbb\xb2",
+    "\xd0\x81",
+    "\xd0\x82",
+    "\xd0\x83",
+    "\xd0\x84",
+    "\xd0\x85",
+    "\xd0\x86",
+    "\xd0\x87",
+    "\xd0\x88",
+    "\xd0\x89",
+    "\xd0\x8a",
+    "\xd0\x8b",
+    "\xd0\x8c",
     "\xc2\xad",
-    "\xc2\xae",
-    "\xc5\xb8",
-    "\xe1\xb8\x9e",
-    "\xe1\xb8\x9f",
-    "\xc4\xa0",
-    "\xc4\xa1",
-    "\xe1\xb9\x80",
-    "\xe1\xb9\x81",
-    "\xc2\xb6",
-    "\xe1\xb9\x96",
-    "\xe1\xba\x81",
-    "\xe1\xb9\x97",
-    "\xe1\xba\x83",
-    "\xe1\xb9\xa0",
-    "\xe1\xbb\xb3",
-    "\xe1\xba\x84",
-    "\xe1\xba\x85",
-    "\xe1\xb9\xa1",
-    "\xc3\x80",
-    "\xc3\x81",
-    "\xc3\x82",
-    "\xc3\x83",
-    "\xc3\x84",
-    "\xc3\x85",
-    "\xc3\x86",
-    "\xc3\x87",
-    "\xc3\x88",
-    "\xc3\x89",
-    "\xc3\x8a",
-    "\xc3\x8b",
-    "\xc3\x8c",
-    "\xc3\x8d",
-    "\xc3\x8e",
-    "\xc3\x8f",
-    "\xc5\xb4",
-    "\xc3\x91",
-    "\xc3\x92",
-    "\xc3\x93",
-    "\xc3\x94",
-    "\xc3\x95",
-    "\xc3\x96",
-    "\xe1\xb9\xaa",
-    "\xc3\x98",
-    "\xc3\x99",
-    "\xc3\x9a",
-    "\xc3\x9b",
-    "\xc3\x9c",
-    "\xc3\x9d",
-    "\xc5\xb6",
-    "\xc3\x9f",
-    "\xc3\xa0",
-    "\xc3\xa1",
-    "\xc3\xa2",
-    "\xc3\xa3",
-    "\xc3\xa4",
-    "\xc3\xa5",
-    "\xc3\xa6",
-    "\xc3\xa7",
-    "\xc3\xa8",
-    "\xc3\xa9",
-    "\xc3\xaa",
-    "\xc3\xab",
-    "\xc3\xac",
-    "\xc3\xad",
-    "\xc3\xae",
-    "\xc3\xaf",
-    "\xc5\xb5",
-    "\xc3\xb1",
-    "\xc3\xb2",
-    "\xc3\xb3",
-    "\xc3\xb4",
-    "\xc3\xb5",
-    "\xc3\xb6",
-    "\xe1\xb9\xab",
-    "\xc3\xb8",
-    "\xc3\xb9",
-    "\xc3\xba",
-    "\xc3\xbb",
-    "\xc3\xbc",
-    "\xc3\xbd",
-    "\xc5\xb7",
-    "\xc3\xbf",
+    "\xd0\x8e",
+    "\xd0\x8f",
+    "\xd0\x90",
+    "\xd0\x91",
+    "\xd0\x92",
+    "\xd0\x93",
+    "\xd0\x94",
+    "\xd0\x95",
+    "\xd0\x96",
+    "\xd0\x97",
+    "\xd0\x98",
+    "\xd0\x99",
+    "\xd0\x9a",
+    "\xd0\x9b",
+    "\xd0\x9c",
+    "\xd0\x9d",
+    "\xd0\x9e",
+    "\xd0\x9f",
+    "\xd0\xa0",
+    "\xd0\xa1",
+    "\xd0\xa2",
+    "\xd0\xa3",
+    "\xd0\xa4",
+    "\xd0\xa5",
+    "\xd0\xa6",
+    "\xd0\xa7",
+    "\xd0\xa8",
+    "\xd0\xa9",
+    "\xd0\xaa",
+    "\xd0\xab",
+    "\xd0\xac",
+    "\xd0\xad",
+    "\xd0\xae",
+    "\xd0\xaf",
+    "\xd0\xb0",
+    "\xd0\xb1",
+    "\xd0\xb2",
+    "\xd0\xb3",
+    "\xd0\xb4",
+    "\xd0\xb5",
+    "\xd0\xb6",
+    "\xd0\xb7",
+    "\xd0\xb8",
+    "\xd0\xb9",
+    "\xd0\xba",
+    "\xd0\xbb",
+    "\xd0\xbc",
+    "\xd0\xbd",
+    "\xd0\xbe",
+    "\xd0\xbf",
+    "\xd1\x80",
+    "\xd1\x81",
+    "\xd1\x82",
+    "\xd1\x83",
+    "\xd1\x84",
+    "\xd1\x85",
+    "\xd1\x86",
+    "\xd1\x87",
+    "\xd1\x88",
+    "\xd1\x89",
+    "\xd1\x8a",
+    "\xd1\x8b",
+    "\xd1\x8c",
+    "\xd1\x8d",
+    "\xd1\x8e",
+    "\xd1\x8f",
+    "\xe2\x84\x96",
+    "\xd1\x91",
+    "\xd1\x92",
+    "\xd1\x93",
+    "\xd1\x94",
+    "\xd1\x95",
+    "\xd1\x96",
+    "\xd1\x97",
+    "\xd1\x98",
+    "\xd1\x99",
+    "\xd1\x9a",
+    "\xd1\x9b",
+    "\xd1\x9c",
+    "\xc2\xa7",
+    "\xd1\x9e",
+    "\xd1\x9f",
 );
 
 my %from_ucs4 = (
@@ -705,101 +705,101 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
-    0x000000a3 => "\xa3",
-    0x000000a7 => "\xa7",
-    0x000000a9 => "\xa9",
+    0x000000a7 => "\xfd",
     0x000000ad => "\xad",
-    0x000000ae => "\xae",
-    0x000000b6 => "\xb6",
-    0x000000c0 => "\xc0",
-    0x000000c1 => "\xc1",
-    0x000000c2 => "\xc2",
-    0x000000c3 => "\xc3",
-    0x000000c4 => "\xc4",
-    0x000000c5 => "\xc5",
-    0x000000c6 => "\xc6",
-    0x000000c7 => "\xc7",
-    0x000000c8 => "\xc8",
-    0x000000c9 => "\xc9",
-    0x000000ca => "\xca",
-    0x000000cb => "\xcb",
-    0x000000cc => "\xcc",
-    0x000000cd => "\xcd",
-    0x000000ce => "\xce",
-    0x000000cf => "\xcf",
-    0x000000d1 => "\xd1",
-    0x000000d2 => "\xd2",
-    0x000000d3 => "\xd3",
-    0x000000d4 => "\xd4",
-    0x000000d5 => "\xd5",
-    0x000000d6 => "\xd6",
-    0x000000d8 => "\xd8",
-    0x000000d9 => "\xd9",
-    0x000000da => "\xda",
-    0x000000db => "\xdb",
-    0x000000dc => "\xdc",
-    0x000000dd => "\xdd",
-    0x000000df => "\xdf",
-    0x000000e0 => "\xe0",
-    0x000000e1 => "\xe1",
-    0x000000e2 => "\xe2",
-    0x000000e3 => "\xe3",
-    0x000000e4 => "\xe4",
-    0x000000e5 => "\xe5",
-    0x000000e6 => "\xe6",
-    0x000000e7 => "\xe7",
-    0x000000e8 => "\xe8",
-    0x000000e9 => "\xe9",
-    0x000000ea => "\xea",
-    0x000000eb => "\xeb",
-    0x000000ec => "\xec",
-    0x000000ed => "\xed",
-    0x000000ee => "\xee",
-    0x000000ef => "\xef",
-    0x000000f1 => "\xf1",
-    0x000000f2 => "\xf2",
-    0x000000f3 => "\xf3",
-    0x000000f4 => "\xf4",
-    0x000000f5 => "\xf5",
-    0x000000f6 => "\xf6",
-    0x000000f8 => "\xf8",
-    0x000000f9 => "\xf9",
-    0x000000fa => "\xfa",
-    0x000000fb => "\xfb",
-    0x000000fc => "\xfc",
-    0x000000fd => "\xfd",
-    0x000000ff => "\xff",
-    0x0000010a => "\xa4",
-    0x0000010b => "\xa5",
-    0x00000120 => "\xb2",
-    0x00000121 => "\xb3",
-    0x00000174 => "\xd0",
-    0x00000175 => "\xf0",
-    0x00000176 => "\xde",
-    0x00000177 => "\xfe",
-    0x00000178 => "\xaf",
-    0x00001e02 => "\xa1",
-    0x00001e03 => "\xa2",
-    0x00001e0a => "\xa6",
-    0x00001e0b => "\xab",
-    0x00001e1e => "\xb0",
-    0x00001e1f => "\xb1",
-    0x00001e40 => "\xb4",
-    0x00001e41 => "\xb5",
-    0x00001e56 => "\xb7",
-    0x00001e57 => "\xb9",
-    0x00001e60 => "\xbb",
-    0x00001e61 => "\xbf",
-    0x00001e6a => "\xd7",
-    0x00001e6b => "\xf7",
-    0x00001e80 => "\xa8",
-    0x00001e81 => "\xb8",
-    0x00001e82 => "\xaa",
-    0x00001e83 => "\xba",
-    0x00001e84 => "\xbd",
-    0x00001e85 => "\xbe",
-    0x00001ef2 => "\xac",
-    0x00001ef3 => "\xbc",
+    0x00000401 => "\xa1",
+    0x00000402 => "\xa2",
+    0x00000403 => "\xa3",
+    0x00000404 => "\xa4",
+    0x00000405 => "\xa5",
+    0x00000406 => "\xa6",
+    0x00000407 => "\xa7",
+    0x00000408 => "\xa8",
+    0x00000409 => "\xa9",
+    0x0000040a => "\xaa",
+    0x0000040b => "\xab",
+    0x0000040c => "\xac",
+    0x0000040e => "\xae",
+    0x0000040f => "\xaf",
+    0x00000410 => "\xb0",
+    0x00000411 => "\xb1",
+    0x00000412 => "\xb2",
+    0x00000413 => "\xb3",
+    0x00000414 => "\xb4",
+    0x00000415 => "\xb5",
+    0x00000416 => "\xb6",
+    0x00000417 => "\xb7",
+    0x00000418 => "\xb8",
+    0x00000419 => "\xb9",
+    0x0000041a => "\xba",
+    0x0000041b => "\xbb",
+    0x0000041c => "\xbc",
+    0x0000041d => "\xbd",
+    0x0000041e => "\xbe",
+    0x0000041f => "\xbf",
+    0x00000420 => "\xc0",
+    0x00000421 => "\xc1",
+    0x00000422 => "\xc2",
+    0x00000423 => "\xc3",
+    0x00000424 => "\xc4",
+    0x00000425 => "\xc5",
+    0x00000426 => "\xc6",
+    0x00000427 => "\xc7",
+    0x00000428 => "\xc8",
+    0x00000429 => "\xc9",
+    0x0000042a => "\xca",
+    0x0000042b => "\xcb",
+    0x0000042c => "\xcc",
+    0x0000042d => "\xcd",
+    0x0000042e => "\xce",
+    0x0000042f => "\xcf",
+    0x00000430 => "\xd0",
+    0x00000431 => "\xd1",
+    0x00000432 => "\xd2",
+    0x00000433 => "\xd3",
+    0x00000434 => "\xd4",
+    0x00000435 => "\xd5",
+    0x00000436 => "\xd6",
+    0x00000437 => "\xd7",
+    0x00000438 => "\xd8",
+    0x00000439 => "\xd9",
+    0x0000043a => "\xda",
+    0x0000043b => "\xdb",
+    0x0000043c => "\xdc",
+    0x0000043d => "\xdd",
+    0x0000043e => "\xde",
+    0x0000043f => "\xdf",
+    0x00000440 => "\xe0",
+    0x00000441 => "\xe1",
+    0x00000442 => "\xe2",
+    0x00000443 => "\xe3",
+    0x00000444 => "\xe4",
+    0x00000445 => "\xe5",
+    0x00000446 => "\xe6",
+    0x00000447 => "\xe7",
+    0x00000448 => "\xe8",
+    0x00000449 => "\xe9",
+    0x0000044a => "\xea",
+    0x0000044b => "\xeb",
+    0x0000044c => "\xec",
+    0x0000044d => "\xed",
+    0x0000044e => "\xee",
+    0x0000044f => "\xef",
+    0x00000451 => "\xf1",
+    0x00000452 => "\xf2",
+    0x00000453 => "\xf3",
+    0x00000454 => "\xf4",
+    0x00000455 => "\xf5",
+    0x00000456 => "\xf6",
+    0x00000457 => "\xf7",
+    0x00000458 => "\xf8",
+    0x00000459 => "\xf9",
+    0x0000045a => "\xfa",
+    0x0000045b => "\xfb",
+    0x0000045c => "\xfc",
+    0x0000045e => "\xfe",
+    0x0000045f => "\xff",
+    0x00002116 => "\xf0",
 );
 
 sub _recode
@@ -827,7 +827,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_14 - Conversion routines for ISO-8859-14
+Locale::RecodeData::ISO_8859_5 - Conversion routines for ISO-8859-5
 
 =head1 SYNOPSIS
 
@@ -836,15 +836,18 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-14.
+routines for ISO-8859-5.
 
 =head1 COMMENTS
 
 The following comments have been extracted from the original charmap:
 
- automatically generated from the charDB
- alias LATIN8
- alias L8
+ version: 1.0
+  source: ECMA registry
+ alias ISO-IR-144
+ alias ISO_8859-5:1988
+ alias ISO_8859-5
+ alias CYRILLIC
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -856,38 +859,38 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
 
  Local | ISO-10646 | Description
 -------+-----------+-------------------------------------------------
-    00 |  00000000 | NULL
-    01 |  00000001 | START OF HEADING
-    02 |  00000002 | START OF TEXT
-    03 |  00000003 | END OF TEXT
-    04 |  00000004 | END OF TRANSMISSION
-    05 |  00000005 | ENQUIRY
-    06 |  00000006 | ACKNOWLEDGE
-    07 |  00000007 | BELL
-    08 |  00000008 | BACKSPACE
-    09 |  00000009 | HORIZONTAL TABULATION
-    0A |  0000000A | LINE FEED
-    0B |  0000000B | VERTICAL TABULATION
-    0C |  0000000C | FORM FEED
-    0D |  0000000D | CARRIAGE RETURN
-    0E |  0000000E | SHIFT OUT
-    0F |  0000000F | SHIFT IN
-    10 |  00000010 | DATA LINK ESCAPE
-    11 |  00000011 | DEVICE CONTROL ONE
-    12 |  00000012 | DEVICE CONTROL TWO
-    13 |  00000013 | DEVICE CONTROL THREE
-    14 |  00000014 | DEVICE CONTROL FOUR
-    15 |  00000015 | NEGATIVE ACKNOWLEDGE
-    16 |  00000016 | SYNCHRONOUS IDLE
-    17 |  00000017 | END OF TRANSMISSION BLOCK
-    18 |  00000018 | CANCEL
-    19 |  00000019 | END OF MEDIUM
-    1A |  0000001A | SUBSTITUTE
-    1B |  0000001B | ESCAPE
-    1C |  0000001C | FILE SEPARATOR
-    1D |  0000001D | GROUP SEPARATOR
-    1E |  0000001E | RECORD SEPARATOR
-    1F |  0000001F | UNIT SEPARATOR
+    00 |  00000000 | NULL (NUL)
+    01 |  00000001 | START OF HEADING (SOH)
+    02 |  00000002 | START OF TEXT (STX)
+    03 |  00000003 | END OF TEXT (ETX)
+    04 |  00000004 | END OF TRANSMISSION (EOT)
+    05 |  00000005 | ENQUIRY (ENQ)
+    06 |  00000006 | ACKNOWLEDGE (ACK)
+    07 |  00000007 | BELL (BEL)
+    08 |  00000008 | BACKSPACE (BS)
+    09 |  00000009 | CHARACTER TABULATION (HT)
+    0A |  0000000A | LINE FEED (LF)
+    0B |  0000000B | LINE TABULATION (VT)
+    0C |  0000000C | FORM FEED (FF)
+    0D |  0000000D | CARRIAGE RETURN (CR)
+    0E |  0000000E | SHIFT OUT (SO)
+    0F |  0000000F | SHIFT IN (SI)
+    10 |  00000010 | DATALINK ESCAPE (DLE)
+    11 |  00000011 | DEVICE CONTROL ONE (DC1)
+    12 |  00000012 | DEVICE CONTROL TWO (DC2)
+    13 |  00000013 | DEVICE CONTROL THREE (DC3)
+    14 |  00000014 | DEVICE CONTROL FOUR (DC4)
+    15 |  00000015 | NEGATIVE ACKNOWLEDGE (NAK)
+    16 |  00000016 | SYNCHRONOUS IDLE (SYN)
+    17 |  00000017 | END OF TRANSMISSION BLOCK (ETB)
+    18 |  00000018 | CANCEL (CAN)
+    19 |  00000019 | END OF MEDIUM (EM)
+    1A |  0000001A | SUBSTITUTE (SUB)
+    1B |  0000001B | ESCAPE (ESC)
+    1C |  0000001C | FILE SEPARATOR (IS4)
+    1D |  0000001D | GROUP SEPARATOR (IS3)
+    1E |  0000001E | RECORD SEPARATOR (IS2)
+    1F |  0000001F | UNIT SEPARATOR (IS1)
     20 |  00000020 | SPACE
     21 |  00000021 | EXCLAMATION MARK
     22 |  00000022 | QUOTATION MARK
@@ -983,7 +986,7 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     7C |  0000007C | VERTICAL LINE
     7D |  0000007D | RIGHT CURLY BRACKET
     7E |  0000007E | TILDE
-    7F |  0000007F | DELETE
+    7F |  0000007F | DELETE (DEL)
     80 |  00000080 | PADDING CHARACTER (PAD)
     81 |  00000081 | HIGH OCTET PRESET (HOP)
     82 |  00000082 | BREAK PERMITTED HERE (BPH)
@@ -1017,106 +1020,106 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  00001E02 | LATIN CAPITAL LETTER B WITH DOT ABOVE
-    A2 |  00001E03 | LATIN SMALL LETTER B WITH DOT ABOVE
-    A3 |  000000A3 | POUND SIGN
-    A4 |  0000010A | LATIN CAPITAL LETTER C WITH DOT ABOVE
-    A5 |  0000010B | LATIN SMALL LETTER C WITH DOT ABOVE
-    A6 |  00001E0A | LATIN CAPITAL LETTER D WITH DOT ABOVE
-    A7 |  000000A7 | SECTION SIGN
-    A8 |  00001E80 | LATIN CAPITAL LETTER W WITH GRAVE
-    A9 |  000000A9 | COPYRIGHT SIGN
-    AA |  00001E82 | LATIN CAPITAL LETTER W WITH ACUTE
-    AB |  00001E0B | LATIN SMALL LETTER D WITH DOT ABOVE
-    AC |  00001EF2 | LATIN CAPITAL LETTER Y WITH GRAVE
+    A1 |  00000401 | CYRILLIC CAPITAL LETTER IO
+    A2 |  00000402 | CYRILLIC CAPITAL LETTER DJE (Serbocroatian)
+    A3 |  00000403 | CYRILLIC CAPITAL LETTER GJE
+    A4 |  00000404 | CYRILLIC CAPITAL LETTER UKRAINIAN IE
+    A5 |  00000405 | CYRILLIC CAPITAL LETTER DZE
+    A6 |  00000406 | CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
+    A7 |  00000407 | CYRILLIC CAPITAL LETTER YI (Ukrainian)
+    A8 |  00000408 | CYRILLIC CAPITAL LETTER JE
+    A9 |  00000409 | CYRILLIC CAPITAL LETTER LJE
+    AA |  0000040A | CYRILLIC CAPITAL LETTER NJE
+    AB |  0000040B | CYRILLIC CAPITAL LETTER TSHE (Serbocroatian)
+    AC |  0000040C | CYRILLIC CAPITAL LETTER KJE
     AD |  000000AD | SOFT HYPHEN
-    AE |  000000AE | REGISTERED SIGN
-    AF |  00000178 | LATIN CAPITAL LETTER Y WITH DIAERESIS
-    B0 |  00001E1E | LATIN CAPITAL LETTER F WITH DOT ABOVE
-    B1 |  00001E1F | LATIN SMALL LETTER F WITH DOT ABOVE
-    B2 |  00000120 | LATIN CAPITAL LETTER G WITH DOT ABOVE
-    B3 |  00000121 | LATIN SMALL LETTER G WITH DOT ABOVE
-    B4 |  00001E40 | LATIN CAPITAL LETTER M WITH DOT ABOVE
-    B5 |  00001E41 | LATIN SMALL LETTER M WITH DOT ABOVE
-    B6 |  000000B6 | PILCROW SIGN
-    B7 |  00001E56 | LATIN CAPITAL LETTER P WITH DOT ABOVE
-    B8 |  00001E81 | LATIN SMALL LETTER W WITH GRAVE
-    B9 |  00001E57 | LATIN SMALL LETTER P WITH DOT ABOVE
-    BA |  00001E83 | LATIN SMALL LETTER W WITH ACUTE
-    BB |  00001E60 | LATIN CAPITAL LETTER S WITH DOT ABOVE
-    BC |  00001EF3 | LATIN SMALL LETTER Y WITH GRAVE
-    BD |  00001E84 | LATIN CAPITAL LETTER W WITH DIAERESIS
-    BE |  00001E85 | LATIN SMALL LETTER W WITH DIAERESIS
-    BF |  00001E61 | LATIN SMALL LETTER S WITH DOT ABOVE
-    C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
-    C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
-    C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
-    C3 |  000000C3 | LATIN CAPITAL LETTER A WITH TILDE
-    C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
-    C5 |  000000C5 | LATIN CAPITAL LETTER A WITH RING ABOVE
-    C6 |  000000C6 | LATIN CAPITAL LETTER AE
-    C7 |  000000C7 | LATIN CAPITAL LETTER C WITH CEDILLA
-    C8 |  000000C8 | LATIN CAPITAL LETTER E WITH GRAVE
-    C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
-    CA |  000000CA | LATIN CAPITAL LETTER E WITH CIRCUMFLEX
-    CB |  000000CB | LATIN CAPITAL LETTER E WITH DIAERESIS
-    CC |  000000CC | LATIN CAPITAL LETTER I WITH GRAVE
-    CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
-    CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
-    CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
-    D0 |  00000174 | LATIN CAPITAL LETTER W WITH CIRCUMFLEX
-    D1 |  000000D1 | LATIN CAPITAL LETTER N WITH TILDE
-    D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
-    D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
-    D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
-    D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
-    D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
-    D7 |  00001E6A | LATIN CAPITAL LETTER T WITH DOT ABOVE
-    D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
-    D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
-    DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
-    DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
-    DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
-    DD |  000000DD | LATIN CAPITAL LETTER Y WITH ACUTE
-    DE |  00000176 | LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
-    DF |  000000DF | LATIN SMALL LETTER SHARP S
-    E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
-    E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
-    E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
-    E3 |  000000E3 | LATIN SMALL LETTER A WITH TILDE
-    E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
-    E5 |  000000E5 | LATIN SMALL LETTER A WITH RING ABOVE
-    E6 |  000000E6 | LATIN SMALL LETTER AE
-    E7 |  000000E7 | LATIN SMALL LETTER C WITH CEDILLA
-    E8 |  000000E8 | LATIN SMALL LETTER E WITH GRAVE
-    E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
-    EA |  000000EA | LATIN SMALL LETTER E WITH CIRCUMFLEX
-    EB |  000000EB | LATIN SMALL LETTER E WITH DIAERESIS
-    EC |  000000EC | LATIN SMALL LETTER I WITH GRAVE
-    ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
-    EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
-    EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
-    F0 |  00000175 | LATIN SMALL LETTER W WITH CIRCUMFLEX
-    F1 |  000000F1 | LATIN SMALL LETTER N WITH TILDE
-    F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
-    F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
-    F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
-    F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
-    F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
-    F7 |  00001E6B | LATIN SMALL LETTER T WITH DOT ABOVE
-    F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
-    F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
-    FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
-    FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
-    FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
-    FD |  000000FD | LATIN SMALL LETTER Y WITH ACUTE
-    FE |  00000177 | LATIN SMALL LETTER Y WITH CIRCUMFLEX
-    FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
+    AE |  0000040E | CYRILLIC CAPITAL LETTER SHORT U (Byelorussian)
+    AF |  0000040F | CYRILLIC CAPITAL LETTER DZHE
+    B0 |  00000410 | CYRILLIC CAPITAL LETTER A
+    B1 |  00000411 | CYRILLIC CAPITAL LETTER BE
+    B2 |  00000412 | CYRILLIC CAPITAL LETTER VE
+    B3 |  00000413 | CYRILLIC CAPITAL LETTER GHE
+    B4 |  00000414 | CYRILLIC CAPITAL LETTER DE
+    B5 |  00000415 | CYRILLIC CAPITAL LETTER IE
+    B6 |  00000416 | CYRILLIC CAPITAL LETTER ZHE
+    B7 |  00000417 | CYRILLIC CAPITAL LETTER ZE
+    B8 |  00000418 | CYRILLIC CAPITAL LETTER I
+    B9 |  00000419 | CYRILLIC CAPITAL LETTER SHORT I
+    BA |  0000041A | CYRILLIC CAPITAL LETTER KA
+    BB |  0000041B | CYRILLIC CAPITAL LETTER EL
+    BC |  0000041C | CYRILLIC CAPITAL LETTER EM
+    BD |  0000041D | CYRILLIC CAPITAL LETTER EN
+    BE |  0000041E | CYRILLIC CAPITAL LETTER O
+    BF |  0000041F | CYRILLIC CAPITAL LETTER PE
+    C0 |  00000420 | CYRILLIC CAPITAL LETTER ER
+    C1 |  00000421 | CYRILLIC CAPITAL LETTER ES
+    C2 |  00000422 | CYRILLIC CAPITAL LETTER TE
+    C3 |  00000423 | CYRILLIC CAPITAL LETTER U
+    C4 |  00000424 | CYRILLIC CAPITAL LETTER EF
+    C5 |  00000425 | CYRILLIC CAPITAL LETTER HA
+    C6 |  00000426 | CYRILLIC CAPITAL LETTER TSE
+    C7 |  00000427 | CYRILLIC CAPITAL LETTER CHE
+    C8 |  00000428 | CYRILLIC CAPITAL LETTER SHA
+    C9 |  00000429 | CYRILLIC CAPITAL LETTER SHCHA
+    CA |  0000042A | CYRILLIC CAPITAL LETTER HARD SIGN
+    CB |  0000042B | CYRILLIC CAPITAL LETTER YERU
+    CC |  0000042C | CYRILLIC CAPITAL LETTER SOFT SIGN
+    CD |  0000042D | CYRILLIC CAPITAL LETTER E
+    CE |  0000042E | CYRILLIC CAPITAL LETTER YU
+    CF |  0000042F | CYRILLIC CAPITAL LETTER YA
+    D0 |  00000430 | CYRILLIC SMALL LETTER A
+    D1 |  00000431 | CYRILLIC SMALL LETTER BE
+    D2 |  00000432 | CYRILLIC SMALL LETTER VE
+    D3 |  00000433 | CYRILLIC SMALL LETTER GHE
+    D4 |  00000434 | CYRILLIC SMALL LETTER DE
+    D5 |  00000435 | CYRILLIC SMALL LETTER IE
+    D6 |  00000436 | CYRILLIC SMALL LETTER ZHE
+    D7 |  00000437 | CYRILLIC SMALL LETTER ZE
+    D8 |  00000438 | CYRILLIC SMALL LETTER I
+    D9 |  00000439 | CYRILLIC SMALL LETTER SHORT I
+    DA |  0000043A | CYRILLIC SMALL LETTER KA
+    DB |  0000043B | CYRILLIC SMALL LETTER EL
+    DC |  0000043C | CYRILLIC SMALL LETTER EM
+    DD |  0000043D | CYRILLIC SMALL LETTER EN
+    DE |  0000043E | CYRILLIC SMALL LETTER O
+    DF |  0000043F | CYRILLIC SMALL LETTER PE
+    E0 |  00000440 | CYRILLIC SMALL LETTER ER
+    E1 |  00000441 | CYRILLIC SMALL LETTER ES
+    E2 |  00000442 | CYRILLIC SMALL LETTER TE
+    E3 |  00000443 | CYRILLIC SMALL LETTER U
+    E4 |  00000444 | CYRILLIC SMALL LETTER EF
+    E5 |  00000445 | CYRILLIC SMALL LETTER HA
+    E6 |  00000446 | CYRILLIC SMALL LETTER TSE
+    E7 |  00000447 | CYRILLIC SMALL LETTER CHE
+    E8 |  00000448 | CYRILLIC SMALL LETTER SHA
+    E9 |  00000449 | CYRILLIC SMALL LETTER SHCHA
+    EA |  0000044A | CYRILLIC SMALL LETTER HARD SIGN
+    EB |  0000044B | CYRILLIC SMALL LETTER YERU
+    EC |  0000044C | CYRILLIC SMALL LETTER SOFT SIGN
+    ED |  0000044D | CYRILLIC SMALL LETTER E
+    EE |  0000044E | CYRILLIC SMALL LETTER YU
+    EF |  0000044F | CYRILLIC SMALL LETTER YA
+    F0 |  00002116 | NUMERO SIGN
+    F1 |  00000451 | CYRILLIC SMALL LETTER IO
+    F2 |  00000452 | CYRILLIC SMALL LETTER DJE (Serbocroatian)
+    F3 |  00000453 | CYRILLIC SMALL LETTER GJE
+    F4 |  00000454 | CYRILLIC SMALL LETTER UKRAINIAN IE
+    F5 |  00000455 | CYRILLIC SMALL LETTER DZE
+    F6 |  00000456 | CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
+    F7 |  00000457 | CYRILLIC SMALL LETTER YI (Ukrainian)
+    F8 |  00000458 | CYRILLIC SMALL LETTER JE
+    F9 |  00000459 | CYRILLIC SMALL LETTER LJE
+    FA |  0000045A | CYRILLIC SMALL LETTER NJE
+    FB |  0000045B | CYRILLIC SMALL LETTER TSHE (Serbocroatian)
+    FC |  0000045C | CYRILLIC SMALL LETTER KJE
+    FD |  000000A7 | SECTION SIGN
+    FE |  0000045E | CYRILLIC SMALL LETTER SHORT U (Byelorussian)
+    FF |  0000045F | CYRILLIC SMALL LETTER DZHE
 
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2016 L<Guido Flohr|http://www.guido-flohr.net/>
+Copyright (C) 2002-2017 L<Guido Flohr|http://www.guido-flohr.net/>
 (L<mailto:guido.flohr@cantanea.com>), all rights reserved.  See the source
 code for details!code for details!
 
